@@ -1,5 +1,5 @@
 package Class::DBI::Loader::mysql;
-# $Id: mysql.pm,v 1.5 2004/02/24 05:48:45 ikebe Exp $
+
 use strict;
 use DBI;
 use Carp ();
@@ -8,28 +8,7 @@ require Class::DBI::Loader::Generic;
 use base qw(Class::DBI::Loader::Generic);
 use vars qw($VERSION);
 
-$VERSION = '0.01';
-
-sub _croak { require Carp; Carp::croak(@_); }
-sub _load_classes {
-    my $self = shift;
-    my $dbh = DBI->connect(@{$self->_datasource}) or _croak($DBI::errstr);
-    foreach my $table($dbh->tables) {
-	my $quoter = $dbh->get_info(29);
-	$table =~ s/$quoter//g;
-	my $class = $self->_table2class($table);
-	no strict 'refs';
-	@{"$class\::ISA"} = qw(Class::DBI::mysql);
-	$class->set_db(Main => @{$self->_datasource});
-	$class->set_up_table($table);
-	$self->{CLASSES}->{$table} = $class;
-    }
-    $dbh->disconnect;
-}
-
-1;
-
-__END__
+$VERSION = '0.04';
 
 =head1 NAME
 
@@ -53,15 +32,30 @@ Class::DBI::Loader::mysql - Class::DBI::Loader mysql implementation.
 
 please see L<Class::DBI::Loader>
 
-=head1 AUTHOR
+=cut
 
-IKEBE Tomohiro E<lt>ikebe@edge.co.jpE<gt>
+sub _croak { require Carp; Carp::croak(@_); }
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+sub _load_classes {
+    my $self = shift;
+    my $dbh = DBI->connect( @{ $self->_datasource } ) or _croak($DBI::errstr);
+    foreach my $table ( $dbh->tables ) {
+        my $quoter = $dbh->get_info(29);
+        $table =~ s/$quoter//g;
+        my $class = $self->_table2class($table);
+        no strict 'refs';
+        @{"$class\::ISA"} = qw(Class::DBI::mysql);
+        $class->set_db( Main => @{ $self->_datasource } );
+        $class->set_up_table($table);
+        $self->{CLASSES}->{$table} = $class;
+    }
+    $dbh->disconnect;
+}
 
 =head1 SEE ALSO
 
 L<Class::DBI::Loader>
 
 =cut
+
+1;
